import { Dispatch, FunctionComponent, Reducer } from 'react';
import { Epic } from '../index';
export declare type Dependencies = {
    service: (task: string) => string;
};
export declare namespace TaskActionTypes {
    const BAD_TASK = "bad_task";
    const SET_TASK = "set_task";
    const START_TASK = "start_task";
}
export declare type TaskState = {
    task: string;
};
export declare type TaskActions = {
    [TaskActionTypes.BAD_TASK]: {
        type: typeof TaskActionTypes.BAD_TASK;
        task: string;
    };
    [TaskActionTypes.SET_TASK]: {
        type: typeof TaskActionTypes.SET_TASK;
        task: string;
    };
    [TaskActionTypes.START_TASK]: {
        type: typeof TaskActionTypes.START_TASK;
        task: string;
    };
};
export declare type TaskReducerAction = TaskActions[typeof TaskActionTypes.SET_TASK];
export declare type TaskAction = TaskReducerAction | TaskActions[typeof TaskActionTypes.BAD_TASK] | TaskActions[typeof TaskActionTypes.START_TASK];
export declare namespace TaskDispatchActions {
    const badTask: (task: string) => TaskActions[typeof TaskActionTypes.BAD_TASK];
    const setTask: (task: string) => TaskActions[typeof TaskActionTypes.SET_TASK];
    const startTask: (task: string) => TaskActions[typeof TaskActionTypes.START_TASK];
}
export declare const defaultState: TaskState;
export declare const taskReducer: Reducer<TaskState, TaskReducerAction>;
export declare namespace ReducerEpics {
    const startTask: Epic<TaskAction, TaskAction, TaskState, Dependencies>;
    const badTask: Epic<TaskAction, TaskAction, TaskState, Dependencies>;
}
export declare type TaskComponentProps = {
    taskName: string;
    useContext: () => {
        dispatch: Dispatch<TaskAction>;
        state: TaskState;
    };
};
export declare const TaskComponent: FunctionComponent<TaskComponentProps>;
